init_kernel_context

Function init_kernel_context 

pub fn init_kernel_context(
    ctx: &mut KernelContext,
    entry_point: fn(),
    stack_top: u64,
)
Initialize a kernel context for first-time execution

This function sets up a kernel context to start executing at the specified entry point when first switched to.

Arguments

  • ctx - Mutable reference to the context to initialize
  • entry_point - Function pointer to start executing
  • stack_top - Top of the stack for this context