pub fn init_kernel_context(
ctx: &mut KernelContext,
entry_point: fn(),
stack_top: u64,
)Expand description
Initialize a kernel context for first-time execution
This function sets up a kernel context to start executing at the specified entry point when first switched to.
Arguments
ctx- Mutable reference to the context to initializeentry_point- Function pointer to start executingstack_top- Top of the stack for this context